@@ -143,8 +143,8 @@ impl Capabilities {
 #[cfg(any(feature = "blocking-client", feature = "async-client"))]
 impl Capabilities {
     fn extract_protocol<'a>(
-        capabilities_or_version: &'a git_packetline::PacketLine<'_>,
-    ) -> Result<(git_packetline::immutable::Text<'a>, Protocol), client::Error> {
+        capabilities_or_version: &'a git_packetline::PacketLineRef<'_>,
+    ) -> Result<(git_packetline::TextRef<'a>, Protocol), client::Error> {
         let first_line = capabilities_or_version
             .as_text()
             .ok_or(client::Error::ExpectedLine("text"))?;
